# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/extensions/quic/connection_debug_visitor/v3/connection_debug_visitor_basic.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/extensions/quic/connection_debug_visitor/v3/connection_debug_visitor_basic.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nVenvoy/extensions/quic/connection_debug_visitor/v3/connection_debug_visitor_basic.proto\x12\x31\x65nvoy.extensions.quic.connection_debug_visitor.v3\x1a\x1dudpa/annotations/status.proto\"\r\n\x0b\x42\x61sicConfigB\xe2\x01\n?io.envoyproxy.envoy.extensions.quic.connection_debug_visitor.v3B ConnectionDebugVisitorBasicProtoP\x01Zsgithub.com/envoyproxy/go-control-plane/envoy/extensions/quic/connection_debug_visitor/v3;connection_debug_visitorv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.quic.connection_debug_visitor.v3.connection_debug_visitor_basic_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n?io.envoyproxy.envoy.extensions.quic.connection_debug_visitor.v3B ConnectionDebugVisitorBasicProtoP\001Zsgithub.com/envoyproxy/go-control-plane/envoy/extensions/quic/connection_debug_visitor/v3;connection_debug_visitorv3\272\200\310\321\006\002\020\002'
  _globals['_BASICCONFIG']._serialized_start=172
  _globals['_BASICCONFIG']._serialized_end=185
# @@protoc_insertion_point(module_scope)
