# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/config/trace/v3/skywalking.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/config/trace/v3/skywalking.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import grpc_service_pb2 as envoy_dot_config_dot_core_dot_v3_dot_grpc__service__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import sensitive_pb2 as udpa_dot_annotations_dot_sensitive__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&envoy/config/trace/v3/skywalking.proto\x12\x15\x65nvoy.config.trace.v3\x1a\'envoy/config/core/v3/grpc_service.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1eudpa/annotations/migrate.proto\x1a udpa/annotations/sensitive.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x91\x01\n\x10SkyWalkingConfig\x12\x41\n\x0cgrpc_service\x18\x01 \x01(\x0b\x32!.envoy.config.core.v3.GrpcServiceB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12:\n\rclient_config\x18\x02 \x01(\x0b\x32#.envoy.config.trace.v3.ClientConfig\"\xad\x01\n\x0c\x43lientConfig\x12\x14\n\x0cservice_name\x18\x01 \x01(\t\x12\x15\n\rinstance_name\x18\x02 \x01(\t\x12\x1f\n\rbackend_token\x18\x03 \x01(\tB\x06\xb8\xb7\x8b\xa4\x02\x01H\x00\x12\x34\n\x0emax_cache_size\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x19\n\x17\x62\x61\x63kend_token_specifierB\xb9\x01\n#io.envoyproxy.envoy.config.trace.v3B\x0fSkywalkingProtoP\x01ZDgithub.com/envoyproxy/go-control-plane/envoy/config/trace/v3;tracev3\xf2\x98\xfe\x8f\x05-\x12+envoy.extensions.tracers.skywalking.v4alpha\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.trace.v3.skywalking_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n#io.envoyproxy.envoy.config.trace.v3B\017SkywalkingProtoP\001ZDgithub.com/envoyproxy/go-control-plane/envoy/config/trace/v3;tracev3\362\230\376\217\005-\022+envoy.extensions.tracers.skywalking.v4alpha\272\200\310\321\006\002\020\002'
  _globals['_SKYWALKINGCONFIG'].fields_by_name['grpc_service']._loaded_options = None
  _globals['_SKYWALKINGCONFIG'].fields_by_name['grpc_service']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_CLIENTCONFIG'].fields_by_name['backend_token']._loaded_options = None
  _globals['_CLIENTCONFIG'].fields_by_name['backend_token']._serialized_options = b'\270\267\213\244\002\001'
  _globals['_SKYWALKINGCONFIG']._serialized_start=261
  _globals['_SKYWALKINGCONFIG']._serialized_end=406
  _globals['_CLIENTCONFIG']._serialized_start=409
  _globals['_CLIENTCONFIG']._serialized_end=582
# @@protoc_insertion_point(module_scope)
