# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/admin/v3/clusters.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/admin/v3/clusters.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.admin.v3 import metrics_pb2 as envoy_dot_admin_dot_v3_dot_metrics__pb2
from envoy.config.cluster.v3 import circuit_breaker_pb2 as envoy_dot_config_dot_cluster_dot_v3_dot_circuit__breaker__pb2
from envoy.config.core.v3 import address_pb2 as envoy_dot_config_dot_core_dot_v3_dot_address__pb2
from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.config.core.v3 import health_check_pb2 as envoy_dot_config_dot_core_dot_v3_dot_health__check__pb2
from envoy.type.v3 import percent_pb2 as envoy_dot_type_dot_v3_dot_percent__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x65nvoy/admin/v3/clusters.proto\x12\x0e\x65nvoy.admin.v3\x1a\x1c\x65nvoy/admin/v3/metrics.proto\x1a-envoy/config/cluster/v3/circuit_breaker.proto\x1a\"envoy/config/core/v3/address.proto\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a\'envoy/config/core/v3/health_check.proto\x1a\x1b\x65nvoy/type/v3/percent.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"h\n\x08\x43lusters\x12\x37\n\x10\x63luster_statuses\x18\x01 \x03(\x0b\x32\x1d.envoy.admin.v3.ClusterStatus:#\x9a\xc5\x88\x1e\x1e\n\x1c\x65nvoy.admin.v2alpha.Clusters\"\x9a\x03\n\rClusterStatus\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\radded_via_api\x18\x02 \x01(\x08\x12?\n\x1fsuccess_rate_ejection_threshold\x18\x03 \x01(\x0b\x32\x16.envoy.type.v3.Percent\x12\x31\n\rhost_statuses\x18\x04 \x03(\x0b\x32\x1a.envoy.admin.v3.HostStatus\x12L\n,local_origin_success_rate_ejection_threshold\x18\x05 \x01(\x0b\x32\x16.envoy.type.v3.Percent\x12\x42\n\x10\x63ircuit_breakers\x18\x06 \x01(\x0b\x32(.envoy.config.cluster.v3.CircuitBreakers\x12\x1a\n\x12observability_name\x18\x07 \x01(\t\x12\x18\n\x10\x65\x64s_service_name\x18\x08 \x01(\t:(\x9a\xc5\x88\x1e#\n!envoy.admin.v2alpha.ClusterStatus\"\x98\x03\n\nHostStatus\x12.\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32\x1d.envoy.config.core.v3.Address\x12+\n\x05stats\x18\x02 \x03(\x0b\x32\x1c.envoy.admin.v3.SimpleMetric\x12\x37\n\rhealth_status\x18\x03 \x01(\x0b\x32 .envoy.admin.v3.HostHealthStatus\x12,\n\x0csuccess_rate\x18\x04 \x01(\x0b\x32\x16.envoy.type.v3.Percent\x12\x0e\n\x06weight\x18\x05 \x01(\r\x12\x10\n\x08hostname\x18\x06 \x01(\t\x12\x10\n\x08priority\x18\x07 \x01(\r\x12\x39\n\x19local_origin_success_rate\x18\x08 \x01(\x0b\x32\x16.envoy.type.v3.Percent\x12\x30\n\x08locality\x18\t \x01(\x0b\x32\x1e.envoy.config.core.v3.Locality:%\x9a\xc5\x88\x1e \n\x1e\x65nvoy.admin.v2alpha.HostStatus\"\xe5\x02\n\x10HostHealthStatus\x12\"\n\x1a\x66\x61iled_active_health_check\x18\x01 \x01(\x08\x12\x1c\n\x14\x66\x61iled_outlier_check\x18\x02 \x01(\x08\x12$\n\x1c\x66\x61iled_active_degraded_check\x18\x04 \x01(\x08\x12\x1f\n\x17pending_dynamic_removal\x18\x05 \x01(\x08\x12\x19\n\x11pending_active_hc\x18\x06 \x01(\x08\x12&\n\x1e\x65xcluded_via_immediate_hc_fail\x18\x07 \x01(\x08\x12\x19\n\x11\x61\x63tive_hc_timeout\x18\x08 \x01(\x08\x12=\n\x11\x65\x64s_health_status\x18\x03 \x01(\x0e\x32\".envoy.config.core.v3.HealthStatus:+\x9a\xc5\x88\x1e&\n$envoy.admin.v2alpha.HostHealthStatusBv\n\x1cio.envoyproxy.envoy.admin.v3B\rClustersProtoP\x01Z=github.com/envoyproxy/go-control-plane/envoy/admin/v3;adminv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.admin.v3.clusters_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034io.envoyproxy.envoy.admin.v3B\rClustersProtoP\001Z=github.com/envoyproxy/go-control-plane/envoy/admin/v3;adminv3\272\200\310\321\006\002\020\002'
  _globals['_CLUSTERS']._loaded_options = None
  _globals['_CLUSTERS']._serialized_options = b'\232\305\210\036\036\n\034envoy.admin.v2alpha.Clusters'
  _globals['_CLUSTERSTATUS']._loaded_options = None
  _globals['_CLUSTERSTATUS']._serialized_options = b'\232\305\210\036#\n!envoy.admin.v2alpha.ClusterStatus'
  _globals['_HOSTSTATUS']._loaded_options = None
  _globals['_HOSTSTATUS']._serialized_options = b'\232\305\210\036 \n\036envoy.admin.v2alpha.HostStatus'
  _globals['_HOSTHEALTHSTATUS']._loaded_options = None
  _globals['_HOSTHEALTHSTATUS']._serialized_options = b'\232\305\210\036&\n$envoy.admin.v2alpha.HostHealthStatus'
  _globals['_CLUSTERS']._serialized_start=331
  _globals['_CLUSTERS']._serialized_end=435
  _globals['_CLUSTERSTATUS']._serialized_start=438
  _globals['_CLUSTERSTATUS']._serialized_end=848
  _globals['_HOSTSTATUS']._serialized_start=851
  _globals['_HOSTSTATUS']._serialized_end=1259
  _globals['_HOSTHEALTHSTATUS']._serialized_start=1262
  _globals['_HOSTHEALTHSTATUS']._serialized_end=1619
# @@protoc_insertion_point(module_scope)
