# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/admin/v3/config_dump.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/admin/v3/config_dump.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.admin.v3 import config_dump_shared_pb2 as envoy_dot_admin_dot_v3_dot_config__dump__shared__pb2
from envoy.config.bootstrap.v3 import bootstrap_pb2 as envoy_dot_config_dot_bootstrap_dot_v3_dot_bootstrap__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n envoy/admin/v3/config_dump.proto\x12\x0e\x65nvoy.admin.v3\x1a\'envoy/admin/v3/config_dump_shared.proto\x1a)envoy/config/bootstrap/v3/bootstrap.proto\x1a\x19google/protobuf/any.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"Z\n\nConfigDump\x12%\n\x07\x63onfigs\x18\x01 \x03(\x0b\x32\x14.google.protobuf.Any:%\x9a\xc5\x88\x1e \n\x1e\x65nvoy.admin.v2alpha.ConfigDump\"\xb0\x01\n\x13\x42ootstrapConfigDump\x12\x37\n\tbootstrap\x18\x01 \x01(\x0b\x32$.envoy.config.bootstrap.v3.Bootstrap\x12\x30\n\x0clast_updated\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp:.\x9a\xc5\x88\x1e)\n\'envoy.admin.v2alpha.BootstrapConfigDump\"\x9e\x06\n\x11SecretsConfigDump\x12\x46\n\x0estatic_secrets\x18\x01 \x03(\x0b\x32..envoy.admin.v3.SecretsConfigDump.StaticSecret\x12O\n\x16\x64ynamic_active_secrets\x18\x02 \x03(\x0b\x32/.envoy.admin.v3.SecretsConfigDump.DynamicSecret\x12P\n\x17\x64ynamic_warming_secrets\x18\x03 \x03(\x0b\x32/.envoy.admin.v3.SecretsConfigDump.DynamicSecret\x1a\xbd\x02\n\rDynamicSecret\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0cversion_info\x18\x02 \x01(\t\x12\x30\n\x0clast_updated\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12$\n\x06secret\x18\x04 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x37\n\x0b\x65rror_state\x18\x05 \x01(\x0b\x32\".envoy.admin.v3.UpdateFailureState\x12;\n\rclient_status\x18\x06 \x01(\x0e\x32$.envoy.admin.v3.ClientResourceStatus::\x9a\xc5\x88\x1e\x35\n3envoy.admin.v2alpha.SecretsConfigDump.DynamicSecret\x1a\xaf\x01\n\x0cStaticSecret\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x30\n\x0clast_updated\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12$\n\x06secret\x18\x03 \x01(\x0b\x32\x14.google.protobuf.Any:9\x9a\xc5\x88\x1e\x34\n2envoy.admin.v2alpha.SecretsConfigDump.StaticSecret:,\x9a\xc5\x88\x1e\'\n%envoy.admin.v2alpha.SecretsConfigDumpBx\n\x1cio.envoyproxy.envoy.admin.v3B\x0f\x43onfigDumpProtoP\x01Z=github.com/envoyproxy/go-control-plane/envoy/admin/v3;adminv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.admin.v3.config_dump_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034io.envoyproxy.envoy.admin.v3B\017ConfigDumpProtoP\001Z=github.com/envoyproxy/go-control-plane/envoy/admin/v3;adminv3\272\200\310\321\006\002\020\002'
  _globals['_CONFIGDUMP']._loaded_options = None
  _globals['_CONFIGDUMP']._serialized_options = b'\232\305\210\036 \n\036envoy.admin.v2alpha.ConfigDump'
  _globals['_BOOTSTRAPCONFIGDUMP']._loaded_options = None
  _globals['_BOOTSTRAPCONFIGDUMP']._serialized_options = b'\232\305\210\036)\n\'envoy.admin.v2alpha.BootstrapConfigDump'
  _globals['_SECRETSCONFIGDUMP_DYNAMICSECRET']._loaded_options = None
  _globals['_SECRETSCONFIGDUMP_DYNAMICSECRET']._serialized_options = b'\232\305\210\0365\n3envoy.admin.v2alpha.SecretsConfigDump.DynamicSecret'
  _globals['_SECRETSCONFIGDUMP_STATICSECRET']._loaded_options = None
  _globals['_SECRETSCONFIGDUMP_STATICSECRET']._serialized_options = b'\232\305\210\0364\n2envoy.admin.v2alpha.SecretsConfigDump.StaticSecret'
  _globals['_SECRETSCONFIGDUMP']._loaded_options = None
  _globals['_SECRETSCONFIGDUMP']._serialized_options = b'\232\305\210\036\'\n%envoy.admin.v2alpha.SecretsConfigDump'
  _globals['_CONFIGDUMP']._serialized_start=262
  _globals['_CONFIGDUMP']._serialized_end=352
  _globals['_BOOTSTRAPCONFIGDUMP']._serialized_start=355
  _globals['_BOOTSTRAPCONFIGDUMP']._serialized_end=531
  _globals['_SECRETSCONFIGDUMP']._serialized_start=534
  _globals['_SECRETSCONFIGDUMP']._serialized_end=1332
  _globals['_SECRETSCONFIGDUMP_DYNAMICSECRET']._serialized_start=791
  _globals['_SECRETSCONFIGDUMP_DYNAMICSECRET']._serialized_end=1108
  _globals['_SECRETSCONFIGDUMP_STATICSECRET']._serialized_start=1111
  _globals['_SECRETSCONFIGDUMP_STATICSECRET']._serialized_end=1286
# @@protoc_insertion_point(module_scope)
