# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/expr/v1alpha1/conformance_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api.expr.v1alpha1 import checked_pb2 as google_dot_api_dot_expr_dot_v1alpha1_dot_checked__pb2
from google.api.expr.v1alpha1 import eval_pb2 as google_dot_api_dot_expr_dot_v1alpha1_dot_eval__pb2
from google.api.expr.v1alpha1 import syntax_pb2 as google_dot_api_dot_expr_dot_v1alpha1_dot_syntax__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2google/api/expr/v1alpha1/conformance_service.proto\x12\x18google.api.expr.v1alpha1\x1a&google/api/expr/v1alpha1/checked.proto\x1a#google/api/expr/v1alpha1/eval.proto\x1a%google/api/expr/v1alpha1/syntax.proto\x1a\x17google/rpc/status.proto\"k\n\x0cParseRequest\x12\x12\n\ncel_source\x18\x01 \x01(\t\x12\x16\n\x0esyntax_version\x18\x02 \x01(\t\x12\x17\n\x0fsource_location\x18\x03 \x01(\t\x12\x16\n\x0e\x64isable_macros\x18\x04 \x01(\x08\"n\n\rParseResponse\x12\x39\n\x0bparsed_expr\x18\x01 \x01(\x0b\x32$.google.api.expr.v1alpha1.ParsedExpr\x12\"\n\x06issues\x18\x02 \x03(\x0b\x32\x12.google.rpc.Status\"\xa2\x01\n\x0c\x43heckRequest\x12\x39\n\x0bparsed_expr\x18\x01 \x01(\x0b\x32$.google.api.expr.v1alpha1.ParsedExpr\x12\x30\n\x08type_env\x18\x02 \x03(\x0b\x32\x1e.google.api.expr.v1alpha1.Decl\x12\x11\n\tcontainer\x18\x03 \x01(\t\x12\x12\n\nno_std_env\x18\x04 \x01(\x08\"p\n\rCheckResponse\x12;\n\x0c\x63hecked_expr\x18\x01 \x01(\x0b\x32%.google.api.expr.v1alpha1.CheckedExpr\x12\"\n\x06issues\x18\x02 \x03(\x0b\x32\x12.google.rpc.Status\"\xc6\x02\n\x0b\x45valRequest\x12;\n\x0bparsed_expr\x18\x01 \x01(\x0b\x32$.google.api.expr.v1alpha1.ParsedExprH\x00\x12=\n\x0c\x63hecked_expr\x18\x02 \x01(\x0b\x32%.google.api.expr.v1alpha1.CheckedExprH\x00\x12\x45\n\x08\x62indings\x18\x03 \x03(\x0b\x32\x33.google.api.expr.v1alpha1.EvalRequest.BindingsEntry\x12\x11\n\tcontainer\x18\x04 \x01(\t\x1aT\n\rBindingsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x32\n\x05value\x18\x02 \x01(\x0b\x32#.google.api.expr.v1alpha1.ExprValue:\x02\x38\x01\x42\x0b\n\texpr_kind\"g\n\x0c\x45valResponse\x12\x33\n\x06result\x18\x01 \x01(\x0b\x32#.google.api.expr.v1alpha1.ExprValue\x12\"\n\x06issues\x18\x02 \x03(\x0b\x32\x12.google.rpc.Status\"\xe8\x01\n\x0cIssueDetails\x12\x41\n\x08severity\x18\x01 \x01(\x0e\x32/.google.api.expr.v1alpha1.IssueDetails.Severity\x12:\n\x08position\x18\x02 \x01(\x0b\x32(.google.api.expr.v1alpha1.SourcePosition\x12\n\n\x02id\x18\x03 \x01(\x03\"M\n\x08Severity\x12\x18\n\x14SEVERITY_UNSPECIFIED\x10\x00\x12\x0f\n\x0b\x44\x45PRECATION\x10\x01\x12\x0b\n\x07WARNING\x10\x02\x12\t\n\x05\x45RROR\x10\x03\x32\xa5\x02\n\x12\x43onformanceService\x12Z\n\x05Parse\x12&.google.api.expr.v1alpha1.ParseRequest\x1a\'.google.api.expr.v1alpha1.ParseResponse\"\x00\x12Z\n\x05\x43heck\x12&.google.api.expr.v1alpha1.CheckRequest\x1a\'.google.api.expr.v1alpha1.CheckResponse\"\x00\x12W\n\x04\x45val\x12%.google.api.expr.v1alpha1.EvalRequest\x1a&.google.api.expr.v1alpha1.EvalResponse\"\x00\x42\x88\x01\n\x1c\x63om.google.api.expr.v1alpha1B\x17\x43onformanceServiceProtoP\x01ZJgoogle.golang.org/genproto/googleapis/api/expr/conformance/v1alpha1;confpb\xf8\x01\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.api.expr.v1alpha1.conformance_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\034com.google.api.expr.v1alpha1B\027ConformanceServiceProtoP\001ZJgoogle.golang.org/genproto/googleapis/api/expr/conformance/v1alpha1;confpb\370\001\001'
  _EVALREQUEST_BINDINGSENTRY._options = None
  _EVALREQUEST_BINDINGSENTRY._serialized_options = b'8\001'
  _globals['_PARSEREQUEST']._serialized_start=221
  _globals['_PARSEREQUEST']._serialized_end=328
  _globals['_PARSERESPONSE']._serialized_start=330
  _globals['_PARSERESPONSE']._serialized_end=440
  _globals['_CHECKREQUEST']._serialized_start=443
  _globals['_CHECKREQUEST']._serialized_end=605
  _globals['_CHECKRESPONSE']._serialized_start=607
  _globals['_CHECKRESPONSE']._serialized_end=719
  _globals['_EVALREQUEST']._serialized_start=722
  _globals['_EVALREQUEST']._serialized_end=1048
  _globals['_EVALREQUEST_BINDINGSENTRY']._serialized_start=951
  _globals['_EVALREQUEST_BINDINGSENTRY']._serialized_end=1035
  _globals['_EVALRESPONSE']._serialized_start=1050
  _globals['_EVALRESPONSE']._serialized_end=1153
  _globals['_ISSUEDETAILS']._serialized_start=1156
  _globals['_ISSUEDETAILS']._serialized_end=1388
  _globals['_ISSUEDETAILS_SEVERITY']._serialized_start=1311
  _globals['_ISSUEDETAILS_SEVERITY']._serialized_end=1388
  _globals['_CONFORMANCESERVICE']._serialized_start=1391
  _globals['_CONFORMANCESERVICE']._serialized_end=1684
# @@protoc_insertion_point(module_scope)
