# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/extensions/wasm/v3/wasm.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/extensions/wasm/v3/wasm.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import backoff_pb2 as envoy_dot_config_dot_core_dot_v3_dot_backoff__pb2
from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from envoy.annotations import deprecation_pb2 as envoy_dot_annotations_dot_deprecation__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#envoy/extensions/wasm/v3/wasm.proto\x12\x18\x65nvoy.extensions.wasm.v3\x1a\"envoy/config/core/v3/backoff.proto\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a\x19google/protobuf/any.proto\x1a#envoy/annotations/deprecation.proto\x1a\x1dudpa/annotations/status.proto\"F\n\x0cReloadConfig\x12\x36\n\x07\x62\x61\x63koff\x18\x01 \x01(\x0b\x32%.envoy.config.core.v3.BackoffStrategy\"\xf5\x01\n\x1b\x43\x61pabilityRestrictionConfig\x12l\n\x14\x61llowed_capabilities\x18\x01 \x03(\x0b\x32N.envoy.extensions.wasm.v3.CapabilityRestrictionConfig.AllowedCapabilitiesEntry\x1ah\n\x18\x41llowedCapabilitiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12;\n\x05value\x18\x02 \x01(\x0b\x32,.envoy.extensions.wasm.v3.SanitizationConfig:\x02\x38\x01\"\x14\n\x12SanitizationConfig\"\x97\x02\n\x08VmConfig\x12\r\n\x05vm_id\x18\x01 \x01(\t\x12\x0f\n\x07runtime\x18\x02 \x01(\t\x12\x33\n\x04\x63ode\x18\x03 \x01(\x0b\x32%.envoy.config.core.v3.AsyncDataSource\x12+\n\rconfiguration\x18\x04 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x19\n\x11\x61llow_precompiled\x18\x05 \x01(\x08\x12\x1f\n\x17nack_on_code_cache_miss\x18\x06 \x01(\x08\x12M\n\x15\x65nvironment_variables\x18\x07 \x01(\x0b\x32..envoy.extensions.wasm.v3.EnvironmentVariables\"\xb2\x01\n\x14\x45nvironmentVariables\x12\x15\n\rhost_env_keys\x18\x01 \x03(\t\x12Q\n\nkey_values\x18\x02 \x03(\x0b\x32=.envoy.extensions.wasm.v3.EnvironmentVariables.KeyValuesEntry\x1a\x30\n\x0eKeyValuesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x97\x03\n\x0cPluginConfig\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07root_id\x18\x02 \x01(\t\x12\x37\n\tvm_config\x18\x03 \x01(\x0b\x32\".envoy.extensions.wasm.v3.VmConfigH\x00\x12+\n\rconfiguration\x18\x04 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x1e\n\tfail_open\x18\x05 \x01(\x08\x42\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0\x12?\n\x0e\x66\x61ilure_policy\x18\x07 \x01(\x0e\x32\'.envoy.extensions.wasm.v3.FailurePolicy\x12=\n\rreload_config\x18\x08 \x01(\x0b\x32&.envoy.extensions.wasm.v3.ReloadConfig\x12\\\n\x1d\x63\x61pability_restriction_config\x18\x06 \x01(\x0b\x32\x35.envoy.extensions.wasm.v3.CapabilityRestrictionConfigB\x04\n\x02vm\"X\n\x0bWasmService\x12\x36\n\x06\x63onfig\x18\x01 \x01(\x0b\x32&.envoy.extensions.wasm.v3.PluginConfig\x12\x11\n\tsingleton\x18\x02 \x01(\x08*Q\n\rFailurePolicy\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0f\n\x0b\x46\x41IL_RELOAD\x10\x01\x12\x0f\n\x0b\x46\x41IL_CLOSED\x10\x02\x12\r\n\tFAIL_OPEN\x10\x03\x42\x85\x01\n&io.envoyproxy.envoy.extensions.wasm.v3B\tWasmProtoP\x01ZFgithub.com/envoyproxy/go-control-plane/envoy/extensions/wasm/v3;wasmv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.wasm.v3.wasm_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n&io.envoyproxy.envoy.extensions.wasm.v3B\tWasmProtoP\001ZFgithub.com/envoyproxy/go-control-plane/envoy/extensions/wasm/v3;wasmv3\272\200\310\321\006\002\020\002'
  _globals['_CAPABILITYRESTRICTIONCONFIG_ALLOWEDCAPABILITIESENTRY']._loaded_options = None
  _globals['_CAPABILITYRESTRICTIONCONFIG_ALLOWEDCAPABILITIESENTRY']._serialized_options = b'8\001'
  _globals['_ENVIRONMENTVARIABLES_KEYVALUESENTRY']._loaded_options = None
  _globals['_ENVIRONMENTVARIABLES_KEYVALUESENTRY']._serialized_options = b'8\001'
  _globals['_PLUGINCONFIG'].fields_by_name['fail_open']._loaded_options = None
  _globals['_PLUGINCONFIG'].fields_by_name['fail_open']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _globals['_FAILUREPOLICY']._serialized_start=1534
  _globals['_FAILUREPOLICY']._serialized_end=1615
  _globals['_RELOADCONFIG']._serialized_start=229
  _globals['_RELOADCONFIG']._serialized_end=299
  _globals['_CAPABILITYRESTRICTIONCONFIG']._serialized_start=302
  _globals['_CAPABILITYRESTRICTIONCONFIG']._serialized_end=547
  _globals['_CAPABILITYRESTRICTIONCONFIG_ALLOWEDCAPABILITIESENTRY']._serialized_start=443
  _globals['_CAPABILITYRESTRICTIONCONFIG_ALLOWEDCAPABILITIESENTRY']._serialized_end=547
  _globals['_SANITIZATIONCONFIG']._serialized_start=549
  _globals['_SANITIZATIONCONFIG']._serialized_end=569
  _globals['_VMCONFIG']._serialized_start=572
  _globals['_VMCONFIG']._serialized_end=851
  _globals['_ENVIRONMENTVARIABLES']._serialized_start=854
  _globals['_ENVIRONMENTVARIABLES']._serialized_end=1032
  _globals['_ENVIRONMENTVARIABLES_KEYVALUESENTRY']._serialized_start=984
  _globals['_ENVIRONMENTVARIABLES_KEYVALUESENTRY']._serialized_end=1032
  _globals['_PLUGINCONFIG']._serialized_start=1035
  _globals['_PLUGINCONFIG']._serialized_end=1442
  _globals['_WASMSERVICE']._serialized_start=1444
  _globals['_WASMSERVICE']._serialized_end=1532
# @@protoc_insertion_point(module_scope)
