# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/service/auth/v2/attribute_context.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/service/auth/v2/attribute_context.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import address_pb2 as envoy_dot_api_dot_v2_dot_core_dot_address__pb2
from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-envoy/service/auth/v2/attribute_context.proto\x12\x15\x65nvoy.service.auth.v2\x1a\x1f\x65nvoy/api/v2/core/address.proto\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dudpa/annotations/status.proto\"\xac\x08\n\x10\x41ttributeContext\x12<\n\x06source\x18\x01 \x01(\x0b\x32,.envoy.service.auth.v2.AttributeContext.Peer\x12\x41\n\x0b\x64\x65stination\x18\x02 \x01(\x0b\x32,.envoy.service.auth.v2.AttributeContext.Peer\x12@\n\x07request\x18\x04 \x01(\x0b\x32/.envoy.service.auth.v2.AttributeContext.Request\x12Z\n\x12\x63ontext_extensions\x18\n \x03(\x0b\x32>.envoy.service.auth.v2.AttributeContext.ContextExtensionsEntry\x12\x35\n\x10metadata_context\x18\x0b \x01(\x0b\x32\x1b.envoy.api.v2.core.Metadata\x1a\xe5\x01\n\x04Peer\x12+\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32\x1a.envoy.api.v2.core.Address\x12\x0f\n\x07service\x18\x02 \x01(\t\x12H\n\x06labels\x18\x03 \x03(\x0b\x32\x38.envoy.service.auth.v2.AttributeContext.Peer.LabelsEntry\x12\x11\n\tprincipal\x18\x04 \x01(\t\x12\x13\n\x0b\x63\x65rtificate\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1av\n\x07Request\x12(\n\x04time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x41\n\x04http\x18\x02 \x01(\x0b\x32\x33.envoy.service.auth.v2.AttributeContext.HttpRequest\x1a\xa7\x02\n\x0bHttpRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06method\x18\x02 \x01(\t\x12Q\n\x07headers\x18\x03 \x03(\x0b\x32@.envoy.service.auth.v2.AttributeContext.HttpRequest.HeadersEntry\x12\x0c\n\x04path\x18\x04 \x01(\t\x12\x0c\n\x04host\x18\x05 \x01(\t\x12\x0e\n\x06scheme\x18\x06 \x01(\t\x12\r\n\x05query\x18\x07 \x01(\t\x12\x10\n\x08\x66ragment\x18\x08 \x01(\t\x12\x0c\n\x04size\x18\t \x01(\x03\x12\x10\n\x08protocol\x18\n \x01(\t\x12\x0c\n\x04\x62ody\x18\x0b \x01(\t\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x38\n\x16\x43ontextExtensionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x8b\x01\n#io.envoyproxy.envoy.service.auth.v2B\x15\x41ttributeContextProtoP\x01ZCgithub.com/envoyproxy/go-control-plane/envoy/service/auth/v2;authv2\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.service.auth.v2.attribute_context_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n#io.envoyproxy.envoy.service.auth.v2B\025AttributeContextProtoP\001ZCgithub.com/envoyproxy/go-control-plane/envoy/service/auth/v2;authv2\272\200\310\321\006\002\020\001'
  _globals['_ATTRIBUTECONTEXT_PEER_LABELSENTRY']._loaded_options = None
  _globals['_ATTRIBUTECONTEXT_PEER_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_ATTRIBUTECONTEXT_HTTPREQUEST_HEADERSENTRY']._loaded_options = None
  _globals['_ATTRIBUTECONTEXT_HTTPREQUEST_HEADERSENTRY']._serialized_options = b'8\001'
  _globals['_ATTRIBUTECONTEXT_CONTEXTEXTENSIONSENTRY']._loaded_options = None
  _globals['_ATTRIBUTECONTEXT_CONTEXTEXTENSIONSENTRY']._serialized_options = b'8\001'
  _globals['_ATTRIBUTECONTEXT']._serialized_start=200
  _globals['_ATTRIBUTECONTEXT']._serialized_end=1268
  _globals['_ATTRIBUTECONTEXT_PEER']._serialized_start=563
  _globals['_ATTRIBUTECONTEXT_PEER']._serialized_end=792
  _globals['_ATTRIBUTECONTEXT_PEER_LABELSENTRY']._serialized_start=747
  _globals['_ATTRIBUTECONTEXT_PEER_LABELSENTRY']._serialized_end=792
  _globals['_ATTRIBUTECONTEXT_REQUEST']._serialized_start=794
  _globals['_ATTRIBUTECONTEXT_REQUEST']._serialized_end=912
  _globals['_ATTRIBUTECONTEXT_HTTPREQUEST']._serialized_start=915
  _globals['_ATTRIBUTECONTEXT_HTTPREQUEST']._serialized_end=1210
  _globals['_ATTRIBUTECONTEXT_HTTPREQUEST_HEADERSENTRY']._serialized_start=1164
  _globals['_ATTRIBUTECONTEXT_HTTPREQUEST_HEADERSENTRY']._serialized_end=1210
  _globals['_ATTRIBUTECONTEXT_CONTEXTEXTENSIONSENTRY']._serialized_start=1212
  _globals['_ATTRIBUTECONTEXT_CONTEXTEXTENSIONSENTRY']._serialized_end=1268
# @@protoc_insertion_point(module_scope)
