# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/extensions/filters/udp/dns_filter/v3/dns_filter.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/extensions/filters/udp/dns_filter/v3/dns_filter.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import address_pb2 as envoy_dot_config_dot_core_dot_v3_dot_address__pb2
from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.config.core.v3 import extension_pb2 as envoy_dot_config_dot_core_dot_v3_dot_extension__pb2
from envoy.config.core.v3 import resolver_pb2 as envoy_dot_config_dot_core_dot_v3_dot_resolver__pb2
from envoy.data.dns.v3 import dns_table_pb2 as envoy_dot_data_dot_dns_dot_v3_dot_dns__table__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from envoy.annotations import deprecation_pb2 as envoy_dot_annotations_dot_deprecation__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;envoy/extensions/filters/udp/dns_filter/v3/dns_filter.proto\x12*envoy.extensions.filters.udp.dns_filter.v3\x1a\"envoy/config/core/v3/address.proto\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a$envoy/config/core/v3/extension.proto\x1a#envoy/config/core/v3/resolver.proto\x1a!envoy/data/dns/v3/dns_table.proto\x1a\x1egoogle/protobuf/duration.proto\x1a#envoy/annotations/deprecation.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x93\x06\n\x0f\x44nsFilterConfig\x12\x1c\n\x0bstat_prefix\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x66\n\rserver_config\x18\x02 \x01(\x0b\x32O.envoy.extensions.filters.udp.dns_filter.v3.DnsFilterConfig.ServerContextConfig\x12\x66\n\rclient_config\x18\x03 \x01(\x0b\x32O.envoy.extensions.filters.udp.dns_filter.v3.DnsFilterConfig.ClientContextConfig\x1a\xa4\x01\n\x13ServerContextConfig\x12\x37\n\x10inline_dns_table\x18\x01 \x01(\x0b\x32\x1b.envoy.data.dns.v3.DnsTableH\x00\x12>\n\x12\x65xternal_dns_table\x18\x02 \x01(\x0b\x32 .envoy.config.core.v3.DataSourceH\x00\x42\x14\n\rconfig_source\x12\x03\xf8\x42\x01\x1a\xea\x02\n\x13\x43lientContextConfig\x12?\n\x10resolver_timeout\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\x42\x07\xaa\x01\x04\x32\x02\x08\x01\x12\x46\n\x12upstream_resolvers\x18\x02 \x03(\x0b\x32\x1d.envoy.config.core.v3.AddressB\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0\x12U\n\x15\x64ns_resolution_config\x18\x05 \x01(\x0b\x32).envoy.config.core.v3.DnsResolutionConfigB\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0\x12M\n\x19typed_dns_resolver_config\x18\x04 \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfig\x12$\n\x13max_pending_lookups\x18\x03 \x01(\x04\x42\x07\xfa\x42\x04\x32\x02(\x01\x42\xb4\x01\n8io.envoyproxy.envoy.extensions.filters.udp.dns_filter.v3B\x0e\x44nsFilterProtoP\x01Z^github.com/envoyproxy/go-control-plane/envoy/extensions/filters/udp/dns_filter/v3;dns_filterv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.udp.dns_filter.v3.dns_filter_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n8io.envoyproxy.envoy.extensions.filters.udp.dns_filter.v3B\016DnsFilterProtoP\001Z^github.com/envoyproxy/go-control-plane/envoy/extensions/filters/udp/dns_filter/v3;dns_filterv3\272\200\310\321\006\002\020\002'
  _globals['_DNSFILTERCONFIG_SERVERCONTEXTCONFIG'].oneofs_by_name['config_source']._loaded_options = None
  _globals['_DNSFILTERCONFIG_SERVERCONTEXTCONFIG'].oneofs_by_name['config_source']._serialized_options = b'\370B\001'
  _globals['_DNSFILTERCONFIG_CLIENTCONTEXTCONFIG'].fields_by_name['resolver_timeout']._loaded_options = None
  _globals['_DNSFILTERCONFIG_CLIENTCONTEXTCONFIG'].fields_by_name['resolver_timeout']._serialized_options = b'\372B\007\252\001\0042\002\010\001'
  _globals['_DNSFILTERCONFIG_CLIENTCONTEXTCONFIG'].fields_by_name['upstream_resolvers']._loaded_options = None
  _globals['_DNSFILTERCONFIG_CLIENTCONTEXTCONFIG'].fields_by_name['upstream_resolvers']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _globals['_DNSFILTERCONFIG_CLIENTCONTEXTCONFIG'].fields_by_name['dns_resolution_config']._loaded_options = None
  _globals['_DNSFILTERCONFIG_CLIENTCONTEXTCONFIG'].fields_by_name['dns_resolution_config']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _globals['_DNSFILTERCONFIG_CLIENTCONTEXTCONFIG'].fields_by_name['max_pending_lookups']._loaded_options = None
  _globals['_DNSFILTERCONFIG_CLIENTCONTEXTCONFIG'].fields_by_name['max_pending_lookups']._serialized_options = b'\372B\0042\002(\001'
  _globals['_DNSFILTERCONFIG'].fields_by_name['stat_prefix']._loaded_options = None
  _globals['_DNSFILTERCONFIG'].fields_by_name['stat_prefix']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_DNSFILTERCONFIG']._serialized_start=412
  _globals['_DNSFILTERCONFIG']._serialized_end=1199
  _globals['_DNSFILTERCONFIG_SERVERCONTEXTCONFIG']._serialized_start=670
  _globals['_DNSFILTERCONFIG_SERVERCONTEXTCONFIG']._serialized_end=834
  _globals['_DNSFILTERCONFIG_CLIENTCONTEXTCONFIG']._serialized_start=837
  _globals['_DNSFILTERCONFIG_CLIENTCONTEXTCONFIG']._serialized_end=1199
# @@protoc_insertion_point(module_scope)
