# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/config/trace/v3/xray.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/config/trace/v3/xray.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import address_pb2 as envoy_dot_config_dot_core_dot_v3_dot_address__pb2
from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n envoy/config/trace/v3/xray.proto\x12\x15\x65nvoy.config.trace.v3\x1a\"envoy/config/core/v3/address.proto\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xe9\x02\n\nXRayConfig\x12<\n\x0f\x64\x61\x65mon_endpoint\x18\x01 \x01(\x0b\x32#.envoy.config.core.v3.SocketAddress\x12\x1d\n\x0csegment_name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12@\n\x16sampling_rule_manifest\x18\x03 \x01(\x0b\x32 .envoy.config.core.v3.DataSource\x12G\n\x0esegment_fields\x18\x04 \x01(\x0b\x32/.envoy.config.trace.v3.XRayConfig.SegmentFields\x1a\x45\n\rSegmentFields\x12\x0e\n\x06origin\x18\x01 \x01(\t\x12$\n\x03\x61ws\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct:,\x9a\xc5\x88\x1e\'\n%envoy.config.trace.v2alpha.XRayConfigB\xad\x01\n#io.envoyproxy.envoy.config.trace.v3B\tXrayProtoP\x01ZDgithub.com/envoyproxy/go-control-plane/envoy/config/trace/v3;tracev3\xf2\x98\xfe\x8f\x05\'\x12%envoy.extensions.tracers.xray.v4alpha\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.trace.v3.xray_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n#io.envoyproxy.envoy.config.trace.v3B\tXrayProtoP\001ZDgithub.com/envoyproxy/go-control-plane/envoy/config/trace/v3;tracev3\362\230\376\217\005\'\022%envoy.extensions.tracers.xray.v4alpha\272\200\310\321\006\002\020\002'
  _globals['_XRAYCONFIG'].fields_by_name['segment_name']._loaded_options = None
  _globals['_XRAYCONFIG'].fields_by_name['segment_name']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_XRAYCONFIG']._loaded_options = None
  _globals['_XRAYCONFIG']._serialized_options = b'\232\305\210\036\'\n%envoy.config.trace.v2alpha.XRayConfig'
  _globals['_XRAYCONFIG']._serialized_start=282
  _globals['_XRAYCONFIG']._serialized_end=643
  _globals['_XRAYCONFIG_SEGMENTFIELDS']._serialized_start=528
  _globals['_XRAYCONFIG_SEGMENTFIELDS']._serialized_end=597
# @@protoc_insertion_point(module_scope)
