# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/extensions/http/custom_response/redirect_policy/v3/redirect_policy.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/extensions/http/custom_response/redirect_policy/v3/redirect_policy.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.config.core.v3 import extension_pb2 as envoy_dot_config_dot_core_dot_v3_dot_extension__pb2
from envoy.config.route.v3 import route_components_pb2 as envoy_dot_config_dot_route_dot_v3_dot_route__components__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from xds.annotations.v3 import status_pb2 as xds_dot_annotations_dot_v3_dot_status__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nNenvoy/extensions/http/custom_response/redirect_policy/v3/redirect_policy.proto\x12\x38\x65nvoy.extensions.http.custom_response.redirect_policy.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a$envoy/config/core/v3/extension.proto\x1a,envoy/config/route/v3/route_components.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1fxds/annotations/v3/status.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xc8\x03\n\x0eRedirectPolicy\x12\x16\n\x03uri\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00\x12@\n\x0fredirect_action\x18\x02 \x01(\x0b\x32%.envoy.config.route.v3.RedirectActionH\x00\x12>\n\x0bstatus_code\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x0b\xfa\x42\x08*\x06\x18\xe7\x07(\xc8\x01\x12S\n\x17response_headers_to_add\x18\x04 \x03(\x0b\x32\'.envoy.config.core.v3.HeaderValueOptionB\t\xfa\x42\x06\x92\x01\x03\x10\xe8\x07\x12R\n\x16request_headers_to_add\x18\x05 \x03(\x0b\x32\'.envoy.config.core.v3.HeaderValueOptionB\t\xfa\x42\x06\x92\x01\x03\x10\xe8\x07\x12Q\n\x1dmodify_request_headers_action\x18\x06 \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfigB \n\x19redirect_action_specifier\x12\x03\xf8\x42\x01\x42\xe2\x01\nFio.envoyproxy.envoy.extensions.http.custom_response.redirect_policy.v3B\x13RedirectPolicyProtoP\x01Zqgithub.com/envoyproxy/go-control-plane/envoy/extensions/http/custom_response/redirect_policy/v3;redirect_policyv3\xba\x80\xc8\xd1\x06\x02\x10\x02\xd2\xc6\xa4\xe1\x06\x02\x08\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.http.custom_response.redirect_policy.v3.redirect_policy_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\nFio.envoyproxy.envoy.extensions.http.custom_response.redirect_policy.v3B\023RedirectPolicyProtoP\001Zqgithub.com/envoyproxy/go-control-plane/envoy/extensions/http/custom_response/redirect_policy/v3;redirect_policyv3\272\200\310\321\006\002\020\002\322\306\244\341\006\002\010\001'
  _globals['_REDIRECTPOLICY'].oneofs_by_name['redirect_action_specifier']._loaded_options = None
  _globals['_REDIRECTPOLICY'].oneofs_by_name['redirect_action_specifier']._serialized_options = b'\370B\001'
  _globals['_REDIRECTPOLICY'].fields_by_name['uri']._loaded_options = None
  _globals['_REDIRECTPOLICY'].fields_by_name['uri']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_REDIRECTPOLICY'].fields_by_name['status_code']._loaded_options = None
  _globals['_REDIRECTPOLICY'].fields_by_name['status_code']._serialized_options = b'\372B\010*\006\030\347\007(\310\001'
  _globals['_REDIRECTPOLICY'].fields_by_name['response_headers_to_add']._loaded_options = None
  _globals['_REDIRECTPOLICY'].fields_by_name['response_headers_to_add']._serialized_options = b'\372B\006\222\001\003\020\350\007'
  _globals['_REDIRECTPOLICY'].fields_by_name['request_headers_to_add']._loaded_options = None
  _globals['_REDIRECTPOLICY'].fields_by_name['request_headers_to_add']._serialized_options = b'\372B\006\222\001\003\020\350\007'
  _globals['_REDIRECTPOLICY']._serialized_start=379
  _globals['_REDIRECTPOLICY']._serialized_end=835
# @@protoc_insertion_point(module_scope)
