# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/extensions/clusters/dynamic_forward_proxy/v3/cluster.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/extensions/clusters/dynamic_forward_proxy/v3/cluster.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.cluster.v3 import cluster_pb2 as envoy_dot_config_dot_cluster_dot_v3_dot_cluster__pb2
from envoy.config.core.v3 import address_pb2 as envoy_dot_config_dot_core_dot_v3_dot_address__pb2
from envoy.extensions.common.dynamic_forward_proxy.v3 import dns_cache_pb2 as envoy_dot_extensions_dot_common_dot_dynamic__forward__proxy_dot_v3_dot_dns__cache__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@envoy/extensions/clusters/dynamic_forward_proxy/v3/cluster.proto\x12\x32\x65nvoy.extensions.clusters.dynamic_forward_proxy.v3\x1a%envoy/config/cluster/v3/cluster.proto\x1a\"envoy/config/core/v3/address.proto\x1a@envoy/extensions/common/dynamic_forward_proxy/v3/dns_cache.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x8d\x03\n\rClusterConfig\x12\\\n\x10\x64ns_cache_config\x18\x01 \x01(\x0b\x32@.envoy.extensions.common.dynamic_forward_proxy.v3.DnsCacheConfigH\x00\x12\x64\n\x13sub_clusters_config\x18\x04 \x01(\x0b\x32\x45.envoy.extensions.clusters.dynamic_forward_proxy.v3.SubClustersConfigH\x00\x12&\n\x1e\x61llow_insecure_cluster_options\x18\x02 \x01(\x08\x12#\n\x1b\x61llow_coalesced_connections\x18\x03 \x01(\x08:G\x9a\xc5\x88\x1e\x42\n@envoy.config.cluster.dynamic_forward_proxy.v2alpha.ClusterConfigB\"\n cluster_implementation_specifier\"\x9c\x02\n\x11SubClustersConfig\x12\x46\n\tlb_policy\x18\x01 \x01(\x0e\x32).envoy.config.cluster.v3.Cluster.LbPolicyB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12?\n\x10max_sub_clusters\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02 \x00\x12<\n\x0fsub_cluster_ttl\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12@\n\x13preresolve_clusters\x18\x04 \x03(\x0b\x32#.envoy.config.core.v3.SocketAddressB\xcd\x01\n@io.envoyproxy.envoy.extensions.clusters.dynamic_forward_proxy.v3B\x0c\x43lusterProtoP\x01Zqgithub.com/envoyproxy/go-control-plane/envoy/extensions/clusters/dynamic_forward_proxy/v3;dynamic_forward_proxyv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.clusters.dynamic_forward_proxy.v3.cluster_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n@io.envoyproxy.envoy.extensions.clusters.dynamic_forward_proxy.v3B\014ClusterProtoP\001Zqgithub.com/envoyproxy/go-control-plane/envoy/extensions/clusters/dynamic_forward_proxy/v3;dynamic_forward_proxyv3\272\200\310\321\006\002\020\002'
  _globals['_CLUSTERCONFIG']._loaded_options = None
  _globals['_CLUSTERCONFIG']._serialized_options = b'\232\305\210\036B\n@envoy.config.cluster.dynamic_forward_proxy.v2alpha.ClusterConfig'
  _globals['_SUBCLUSTERSCONFIG'].fields_by_name['lb_policy']._loaded_options = None
  _globals['_SUBCLUSTERSCONFIG'].fields_by_name['lb_policy']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_SUBCLUSTERSCONFIG'].fields_by_name['max_sub_clusters']._loaded_options = None
  _globals['_SUBCLUSTERSCONFIG'].fields_by_name['max_sub_clusters']._serialized_options = b'\372B\004*\002 \000'
  _globals['_SUBCLUSTERSCONFIG'].fields_by_name['sub_cluster_ttl']._loaded_options = None
  _globals['_SUBCLUSTERSCONFIG'].fields_by_name['sub_cluster_ttl']._serialized_options = b'\372B\005\252\001\002*\000'
  _globals['_CLUSTERCONFIG']._serialized_start=417
  _globals['_CLUSTERCONFIG']._serialized_end=814
  _globals['_SUBCLUSTERSCONFIG']._serialized_start=817
  _globals['_SUBCLUSTERSCONFIG']._serialized_end=1101
# @@protoc_insertion_point(module_scope)
