# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/api/v2/auth/common.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/api/v2/auth/common.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from envoy.type.matcher import string_pb2 as envoy_dot_type_dot_matcher_dot_string__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import sensitive_pb2 as udpa_dot_annotations_dot_sensitive__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x65nvoy/api/v2/auth/common.proto\x12\x11\x65nvoy.api.v2.auth\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a\x1f\x65nvoy/type/matcher/string.proto\x1a\x19google/protobuf/any.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1eudpa/annotations/migrate.proto\x1a udpa/annotations/sensitive.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xc8\x02\n\rTlsParameters\x12\\\n\x1ctls_minimum_protocol_version\x18\x01 \x01(\x0e\x32,.envoy.api.v2.auth.TlsParameters.TlsProtocolB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\\\n\x1ctls_maximum_protocol_version\x18\x02 \x01(\x0e\x32,.envoy.api.v2.auth.TlsParameters.TlsProtocolB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x15\n\rcipher_suites\x18\x03 \x03(\t\x12\x13\n\x0b\x65\x63\x64h_curves\x18\x04 \x03(\t\"O\n\x0bTlsProtocol\x12\x0c\n\x08TLS_AUTO\x10\x00\x12\x0b\n\x07TLSv1_0\x10\x01\x12\x0b\n\x07TLSv1_1\x10\x02\x12\x0b\n\x07TLSv1_2\x10\x03\x12\x0b\n\x07TLSv1_3\x10\x04\"\xae\x01\n\x12PrivateKeyProvider\x12\x1e\n\rprovider_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x33\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructB\x08\x18\x01\xb8\xb7\x8b\xa4\x02\x01H\x00\x12\x34\n\x0ctyped_config\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyB\x06\xb8\xb7\x8b\xa4\x02\x01H\x00\x42\r\n\x0b\x63onfig_type\"\xfd\x02\n\x0eTlsCertificate\x12\x38\n\x11\x63\x65rtificate_chain\x18\x01 \x01(\x0b\x32\x1d.envoy.api.v2.core.DataSource\x12:\n\x0bprivate_key\x18\x02 \x01(\x0b\x32\x1d.envoy.api.v2.core.DataSourceB\x06\xb8\xb7\x8b\xa4\x02\x01\x12\x43\n\x14private_key_provider\x18\x06 \x01(\x0b\x32%.envoy.api.v2.auth.PrivateKeyProvider\x12\x37\n\x08password\x18\x03 \x01(\x0b\x32\x1d.envoy.api.v2.core.DataSourceB\x06\xb8\xb7\x8b\xa4\x02\x01\x12\x32\n\x0bocsp_staple\x18\x04 \x01(\x0b\x32\x1d.envoy.api.v2.core.DataSource\x12\x43\n\x1csigned_certificate_timestamp\x18\x05 \x03(\x0b\x32\x1d.envoy.api.v2.core.DataSource\"S\n\x14TlsSessionTicketKeys\x12;\n\x04keys\x18\x01 \x03(\x0b\x32\x1d.envoy.api.v2.core.DataSourceB\x0e\xfa\x42\x05\x92\x01\x02\x08\x01\xb8\xb7\x8b\xa4\x02\x01\"\xaa\x05\n\x1c\x43\x65rtificateValidationContext\x12\x31\n\ntrusted_ca\x18\x01 \x01(\x0b\x32\x1d.envoy.api.v2.core.DataSource\x12/\n\x17verify_certificate_spki\x18\x03 \x03(\tB\x0e\xfa\x42\x0b\x92\x01\x08\"\x06r\x04 ,(,\x12/\n\x17verify_certificate_hash\x18\x02 \x03(\tB\x0e\xfa\x42\x0b\x92\x01\x08\"\x06r\x04 @(_\x12#\n\x17verify_subject_alt_name\x18\x04 \x03(\tB\x02\x18\x01\x12\x42\n\x17match_subject_alt_names\x18\t \x03(\x0b\x32!.envoy.type.matcher.StringMatcher\x12\x37\n\x13require_ocsp_staple\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12H\n$require_signed_certificate_timestamp\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12*\n\x03\x63rl\x18\x07 \x01(\x0b\x32\x1d.envoy.api.v2.core.DataSource\x12!\n\x19\x61llow_expired_certificate\x18\x08 \x01(\x08\x12r\n\x18trust_chain_verification\x18\n \x01(\x0e\x32\x46.envoy.api.v2.auth.CertificateValidationContext.TrustChainVerificationB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\"F\n\x16TrustChainVerification\x12\x16\n\x12VERIFY_TRUST_CHAIN\x10\x00\x12\x14\n\x10\x41\x43\x43\x45PT_UNTRUSTED\x10\x01\x42\xa3\x01\n\x1fio.envoyproxy.envoy.api.v2.authB\x0b\x43ommonProtoP\x01Z8github.com/envoyproxy/go-control-plane/envoy/api/v2/auth\xf2\x98\xfe\x8f\x05+\x12)envoy.extensions.transport_sockets.tls.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.api.v2.auth.common_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\037io.envoyproxy.envoy.api.v2.authB\013CommonProtoP\001Z8github.com/envoyproxy/go-control-plane/envoy/api/v2/auth\362\230\376\217\005+\022)envoy.extensions.transport_sockets.tls.v3\272\200\310\321\006\002\020\001'
  _globals['_TLSPARAMETERS'].fields_by_name['tls_minimum_protocol_version']._loaded_options = None
  _globals['_TLSPARAMETERS'].fields_by_name['tls_minimum_protocol_version']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_TLSPARAMETERS'].fields_by_name['tls_maximum_protocol_version']._loaded_options = None
  _globals['_TLSPARAMETERS'].fields_by_name['tls_maximum_protocol_version']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_PRIVATEKEYPROVIDER'].fields_by_name['provider_name']._loaded_options = None
  _globals['_PRIVATEKEYPROVIDER'].fields_by_name['provider_name']._serialized_options = b'\372B\004r\002 \001'
  _globals['_PRIVATEKEYPROVIDER'].fields_by_name['config']._loaded_options = None
  _globals['_PRIVATEKEYPROVIDER'].fields_by_name['config']._serialized_options = b'\030\001\270\267\213\244\002\001'
  _globals['_PRIVATEKEYPROVIDER'].fields_by_name['typed_config']._loaded_options = None
  _globals['_PRIVATEKEYPROVIDER'].fields_by_name['typed_config']._serialized_options = b'\270\267\213\244\002\001'
  _globals['_TLSCERTIFICATE'].fields_by_name['private_key']._loaded_options = None
  _globals['_TLSCERTIFICATE'].fields_by_name['private_key']._serialized_options = b'\270\267\213\244\002\001'
  _globals['_TLSCERTIFICATE'].fields_by_name['password']._loaded_options = None
  _globals['_TLSCERTIFICATE'].fields_by_name['password']._serialized_options = b'\270\267\213\244\002\001'
  _globals['_TLSSESSIONTICKETKEYS'].fields_by_name['keys']._loaded_options = None
  _globals['_TLSSESSIONTICKETKEYS'].fields_by_name['keys']._serialized_options = b'\372B\005\222\001\002\010\001\270\267\213\244\002\001'
  _globals['_CERTIFICATEVALIDATIONCONTEXT'].fields_by_name['verify_certificate_spki']._loaded_options = None
  _globals['_CERTIFICATEVALIDATIONCONTEXT'].fields_by_name['verify_certificate_spki']._serialized_options = b'\372B\013\222\001\010\"\006r\004 ,(,'
  _globals['_CERTIFICATEVALIDATIONCONTEXT'].fields_by_name['verify_certificate_hash']._loaded_options = None
  _globals['_CERTIFICATEVALIDATIONCONTEXT'].fields_by_name['verify_certificate_hash']._serialized_options = b'\372B\013\222\001\010\"\006r\004 @(_'
  _globals['_CERTIFICATEVALIDATIONCONTEXT'].fields_by_name['verify_subject_alt_name']._loaded_options = None
  _globals['_CERTIFICATEVALIDATIONCONTEXT'].fields_by_name['verify_subject_alt_name']._serialized_options = b'\030\001'
  _globals['_CERTIFICATEVALIDATIONCONTEXT'].fields_by_name['trust_chain_verification']._loaded_options = None
  _globals['_CERTIFICATEVALIDATIONCONTEXT'].fields_by_name['trust_chain_verification']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_TLSPARAMETERS']._serialized_start=328
  _globals['_TLSPARAMETERS']._serialized_end=656
  _globals['_TLSPARAMETERS_TLSPROTOCOL']._serialized_start=577
  _globals['_TLSPARAMETERS_TLSPROTOCOL']._serialized_end=656
  _globals['_PRIVATEKEYPROVIDER']._serialized_start=659
  _globals['_PRIVATEKEYPROVIDER']._serialized_end=833
  _globals['_TLSCERTIFICATE']._serialized_start=836
  _globals['_TLSCERTIFICATE']._serialized_end=1217
  _globals['_TLSSESSIONTICKETKEYS']._serialized_start=1219
  _globals['_TLSSESSIONTICKETKEYS']._serialized_end=1302
  _globals['_CERTIFICATEVALIDATIONCONTEXT']._serialized_start=1305
  _globals['_CERTIFICATEVALIDATIONCONTEXT']._serialized_end=1987
  _globals['_CERTIFICATEVALIDATIONCONTEXT_TRUSTCHAINVERIFICATION']._serialized_start=1917
  _globals['_CERTIFICATEVALIDATIONCONTEXT_TRUSTCHAINVERIFICATION']._serialized_end=1987
# @@protoc_insertion_point(module_scope)
