# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/extensions/upstreams/http/v3/http_protocol_options.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/extensions/upstreams/http/v3/http_protocol_options.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import extension_pb2 as envoy_dot_config_dot_core_dot_v3_dot_extension__pb2
from envoy.config.core.v3 import protocol_pb2 as envoy_dot_config_dot_core_dot_v3_dot_protocol__pb2
from envoy.extensions.filters.network.http_connection_manager.v3 import http_connection_manager_pb2 as envoy_dot_extensions_dot_filters_dot_network_dot_http__connection__manager_dot_v3_dot_http__connection__manager__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>envoy/extensions/upstreams/http/v3/http_protocol_options.proto\x12\"envoy.extensions.upstreams.http.v3\x1a$envoy/config/core/v3/extension.proto\x1a#envoy/config/core/v3/protocol.proto\x1aYenvoy/extensions/filters/network/http_connection_manager/v3/http_connection_manager.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xc4\x0c\n\x13HttpProtocolOptions\x12O\n\x1c\x63ommon_http_protocol_options\x18\x01 \x01(\x0b\x32).envoy.config.core.v3.HttpProtocolOptions\x12Y\n\x1eupstream_http_protocol_options\x18\x02 \x01(\x0b\x32\x31.envoy.config.core.v3.UpstreamHttpProtocolOptions\x12j\n\x14\x65xplicit_http_config\x18\x03 \x01(\x0b\x32J.envoy.extensions.upstreams.http.v3.HttpProtocolOptions.ExplicitHttpConfigH\x00\x12y\n\x1euse_downstream_protocol_config\x18\x04 \x01(\x0b\x32O.envoy.extensions.upstreams.http.v3.HttpProtocolOptions.UseDownstreamHttpConfigH\x00\x12]\n\x0b\x61uto_config\x18\x05 \x01(\x0b\x32\x46.envoy.extensions.upstreams.http.v3.HttpProtocolOptions.AutoHttpConfigH\x00\x12]\n\x0chttp_filters\x18\x06 \x03(\x0b\x32G.envoy.extensions.filters.network.http_connection_manager.v3.HttpFilter\x12L\n\x18header_validation_config\x18\x07 \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfig\x1a\x95\x02\n\x12\x45xplicitHttpConfig\x12K\n\x15http_protocol_options\x18\x01 \x01(\x0b\x32*.envoy.config.core.v3.Http1ProtocolOptionsH\x00\x12L\n\x16http2_protocol_options\x18\x02 \x01(\x0b\x32*.envoy.config.core.v3.Http2ProtocolOptionsH\x00\x12L\n\x16http3_protocol_options\x18\x03 \x01(\x0b\x32*.envoy.config.core.v3.Http3ProtocolOptionsH\x00\x42\x16\n\x0fprotocol_config\x12\x03\xf8\x42\x01\x1a\xfc\x01\n\x17UseDownstreamHttpConfig\x12I\n\x15http_protocol_options\x18\x01 \x01(\x0b\x32*.envoy.config.core.v3.Http1ProtocolOptions\x12J\n\x16http2_protocol_options\x18\x02 \x01(\x0b\x32*.envoy.config.core.v3.Http2ProtocolOptions\x12J\n\x16http3_protocol_options\x18\x03 \x01(\x0b\x32*.envoy.config.core.v3.Http3ProtocolOptions\x1a\xd4\x02\n\x0e\x41utoHttpConfig\x12I\n\x15http_protocol_options\x18\x01 \x01(\x0b\x32*.envoy.config.core.v3.Http1ProtocolOptions\x12J\n\x16http2_protocol_options\x18\x02 \x01(\x0b\x32*.envoy.config.core.v3.Http2ProtocolOptions\x12J\n\x16http3_protocol_options\x18\x03 \x01(\x0b\x32*.envoy.config.core.v3.Http3ProtocolOptions\x12_\n!alternate_protocols_cache_options\x18\x04 \x01(\x0b\x32\x34.envoy.config.core.v3.AlternateProtocolsCacheOptionsB \n\x19upstream_protocol_options\x12\x03\xf8\x42\x01\x42\xa8\x01\n0io.envoyproxy.envoy.extensions.upstreams.http.v3B\x18HttpProtocolOptionsProtoP\x01ZPgithub.com/envoyproxy/go-control-plane/envoy/extensions/upstreams/http/v3;httpv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.upstreams.http.v3.http_protocol_options_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n0io.envoyproxy.envoy.extensions.upstreams.http.v3B\030HttpProtocolOptionsProtoP\001ZPgithub.com/envoyproxy/go-control-plane/envoy/extensions/upstreams/http/v3;httpv3\272\200\310\321\006\002\020\002'
  _globals['_HTTPPROTOCOLOPTIONS_EXPLICITHTTPCONFIG'].oneofs_by_name['protocol_config']._loaded_options = None
  _globals['_HTTPPROTOCOLOPTIONS_EXPLICITHTTPCONFIG'].oneofs_by_name['protocol_config']._serialized_options = b'\370B\001'
  _globals['_HTTPPROTOCOLOPTIONS'].oneofs_by_name['upstream_protocol_options']._loaded_options = None
  _globals['_HTTPPROTOCOLOPTIONS'].oneofs_by_name['upstream_protocol_options']._serialized_options = b'\370B\001'
  _globals['_HTTPPROTOCOLOPTIONS']._serialized_start=325
  _globals['_HTTPPROTOCOLOPTIONS']._serialized_end=1929
  _globals['_HTTPPROTOCOLOPTIONS_EXPLICITHTTPCONFIG']._serialized_start=1020
  _globals['_HTTPPROTOCOLOPTIONS_EXPLICITHTTPCONFIG']._serialized_end=1297
  _globals['_HTTPPROTOCOLOPTIONS_USEDOWNSTREAMHTTPCONFIG']._serialized_start=1300
  _globals['_HTTPPROTOCOLOPTIONS_USEDOWNSTREAMHTTPCONFIG']._serialized_end=1552
  _globals['_HTTPPROTOCOLOPTIONS_AUTOHTTPCONFIG']._serialized_start=1555
  _globals['_HTTPPROTOCOLOPTIONS_AUTOHTTPCONFIG']._serialized_end=1895
# @@protoc_insertion_point(module_scope)
