# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/data/tap/v3/transport.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/data/tap/v3/transport.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.data.tap.v3 import common_pb2 as envoy_dot_data_dot_tap_dot_v3_dot_common__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!envoy/data/tap/v3/transport.proto\x12\x11\x65nvoy.data.tap.v3\x1a\x1e\x65nvoy/data/tap/v3/common.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"\xae\x04\n\x0bSocketEvent\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x33\n\x04read\x18\x02 \x01(\x0b\x32#.envoy.data.tap.v3.SocketEvent.ReadH\x00\x12\x35\n\x05write\x18\x03 \x01(\x0b\x32$.envoy.data.tap.v3.SocketEvent.WriteH\x00\x12\x37\n\x06\x63losed\x18\x04 \x01(\x0b\x32%.envoy.data.tap.v3.SocketEvent.ClosedH\x00\x1a]\n\x04Read\x12%\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x17.envoy.data.tap.v3.Body:.\x9a\xc5\x88\x1e)\n\'envoy.data.tap.v2alpha.SocketEvent.Read\x1as\n\x05Write\x12%\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x17.envoy.data.tap.v3.Body\x12\x12\n\nend_stream\x18\x02 \x01(\x08:/\x9a\xc5\x88\x1e*\n(envoy.data.tap.v2alpha.SocketEvent.Write\x1a:\n\x06\x43losed:0\x9a\xc5\x88\x1e+\n)envoy.data.tap.v2alpha.SocketEvent.Closed:)\x9a\xc5\x88\x1e$\n\"envoy.data.tap.v2alpha.SocketEventB\x10\n\x0e\x65vent_selector\"\xee\x01\n\x13SocketBufferedTrace\x12\x10\n\x08trace_id\x18\x01 \x01(\x04\x12\x31\n\nconnection\x18\x02 \x01(\x0b\x32\x1d.envoy.data.tap.v3.Connection\x12.\n\x06\x65vents\x18\x03 \x03(\x0b\x32\x1e.envoy.data.tap.v3.SocketEvent\x12\x16\n\x0eread_truncated\x18\x04 \x01(\x08\x12\x17\n\x0fwrite_truncated\x18\x05 \x01(\x08:1\x9a\xc5\x88\x1e,\n*envoy.data.tap.v2alpha.SocketBufferedTrace\"\xdf\x01\n\x1aSocketStreamedTraceSegment\x12\x10\n\x08trace_id\x18\x01 \x01(\x04\x12\x33\n\nconnection\x18\x02 \x01(\x0b\x32\x1d.envoy.data.tap.v3.ConnectionH\x00\x12/\n\x05\x65vent\x18\x03 \x01(\x0b\x32\x1e.envoy.data.tap.v3.SocketEventH\x00:8\x9a\xc5\x88\x1e\x33\n1envoy.data.tap.v2alpha.SocketStreamedTraceSegmentB\x0f\n\rmessage_pieceB{\n\x1fio.envoyproxy.envoy.data.tap.v3B\x0eTransportProtoP\x01Z>github.com/envoyproxy/go-control-plane/envoy/data/tap/v3;tapv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.data.tap.v3.transport_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\037io.envoyproxy.envoy.data.tap.v3B\016TransportProtoP\001Z>github.com/envoyproxy/go-control-plane/envoy/data/tap/v3;tapv3\272\200\310\321\006\002\020\002'
  _globals['_SOCKETEVENT_READ']._loaded_options = None
  _globals['_SOCKETEVENT_READ']._serialized_options = b'\232\305\210\036)\n\'envoy.data.tap.v2alpha.SocketEvent.Read'
  _globals['_SOCKETEVENT_WRITE']._loaded_options = None
  _globals['_SOCKETEVENT_WRITE']._serialized_options = b'\232\305\210\036*\n(envoy.data.tap.v2alpha.SocketEvent.Write'
  _globals['_SOCKETEVENT_CLOSED']._loaded_options = None
  _globals['_SOCKETEVENT_CLOSED']._serialized_options = b'\232\305\210\036+\n)envoy.data.tap.v2alpha.SocketEvent.Closed'
  _globals['_SOCKETEVENT']._loaded_options = None
  _globals['_SOCKETEVENT']._serialized_options = b'\232\305\210\036$\n\"envoy.data.tap.v2alpha.SocketEvent'
  _globals['_SOCKETBUFFEREDTRACE']._loaded_options = None
  _globals['_SOCKETBUFFEREDTRACE']._serialized_options = b'\232\305\210\036,\n*envoy.data.tap.v2alpha.SocketBufferedTrace'
  _globals['_SOCKETSTREAMEDTRACESEGMENT']._loaded_options = None
  _globals['_SOCKETSTREAMEDTRACESEGMENT']._serialized_options = b'\232\305\210\0363\n1envoy.data.tap.v2alpha.SocketStreamedTraceSegment'
  _globals['_SOCKETEVENT']._serialized_start=188
  _globals['_SOCKETEVENT']._serialized_end=746
  _globals['_SOCKETEVENT_READ']._serialized_start=415
  _globals['_SOCKETEVENT_READ']._serialized_end=508
  _globals['_SOCKETEVENT_WRITE']._serialized_start=510
  _globals['_SOCKETEVENT_WRITE']._serialized_end=625
  _globals['_SOCKETEVENT_CLOSED']._serialized_start=627
  _globals['_SOCKETEVENT_CLOSED']._serialized_end=685
  _globals['_SOCKETBUFFEREDTRACE']._serialized_start=749
  _globals['_SOCKETBUFFEREDTRACE']._serialized_end=987
  _globals['_SOCKETSTREAMEDTRACESEGMENT']._serialized_start=990
  _globals['_SOCKETSTREAMEDTRACESEGMENT']._serialized_end=1213
# @@protoc_insertion_point(module_scope)
