# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/api/v2/listener/listener_components.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/api/v2/listener/listener_components.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.auth import tls_pb2 as envoy_dot_api_dot_v2_dot_auth_dot_tls__pb2
from envoy.api.v2.core import address_pb2 as envoy_dot_api_dot_v2_dot_core_dot_address__pb2
from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from envoy.type import range_pb2 as envoy_dot_type_dot_range__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/envoy/api/v2/listener/listener_components.proto\x12\x15\x65nvoy.api.v2.listener\x1a\x1b\x65nvoy/api/v2/auth/tls.proto\x1a\x1f\x65nvoy/api/v2/core/address.proto\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a\x16\x65nvoy/type/range.proto\x1a\x19google/protobuf/any.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x91\x01\n\x06\x46ilter\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12-\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructB\x02\x18\x01H\x00\x12,\n\x0ctyped_config\x18\x04 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x42\r\n\x0b\x63onfig_typeJ\x04\x08\x03\x10\x04\"\xc5\x04\n\x10\x46ilterChainMatch\x12\x43\n\x10\x64\x65stination_port\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x0b\xfa\x42\x08*\x06\x18\xff\xff\x03(\x01\x12\x33\n\rprefix_ranges\x18\x03 \x03(\x0b\x32\x1c.envoy.api.v2.core.CidrRange\x12\x16\n\x0e\x61\x64\x64ress_suffix\x18\x04 \x01(\t\x12\x30\n\nsuffix_len\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12[\n\x0bsource_type\x18\x0c \x01(\x0e\x32<.envoy.api.v2.listener.FilterChainMatch.ConnectionSourceTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12:\n\x14source_prefix_ranges\x18\x06 \x03(\x0b\x32\x1c.envoy.api.v2.core.CidrRange\x12&\n\x0csource_ports\x18\x07 \x03(\rB\x10\xfa\x42\r\x92\x01\n\"\x08*\x06\x18\xff\xff\x03(\x01\x12\x14\n\x0cserver_names\x18\x0b \x03(\t\x12\x1a\n\x12transport_protocol\x18\t \x01(\t\x12\x1d\n\x15\x61pplication_protocols\x18\n \x03(\t\"U\n\x14\x43onnectionSourceType\x12\x07\n\x03\x41NY\x10\x00\x12&\n\x05LOCAL\x10\x01\x1a\x1b\xf2\x98\xfe\x8f\x05\x15\n\x13SAME_IP_OR_LOOPBACK\x12\x0c\n\x08\x45XTERNAL\x10\x02J\x04\x08\x01\x10\x02\"\xf4\x02\n\x0b\x46ilterChain\x12\x43\n\x12\x66ilter_chain_match\x18\x01 \x01(\x0b\x32\'.envoy.api.v2.listener.FilterChainMatch\x12@\n\x0btls_context\x18\x02 \x01(\x0b\x32\'.envoy.api.v2.auth.DownstreamTlsContextB\x02\x18\x01\x12.\n\x07\x66ilters\x18\x03 \x03(\x0b\x32\x1d.envoy.api.v2.listener.Filter\x12\x33\n\x0fuse_proxy_proto\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12-\n\x08metadata\x18\x05 \x01(\x0b\x32\x1b.envoy.api.v2.core.Metadata\x12<\n\x10transport_socket\x18\x06 \x01(\x0b\x32\".envoy.api.v2.core.TransportSocket\x12\x0c\n\x04name\x18\x07 \x01(\t\"\xe5\x03\n!ListenerFilterChainMatchPredicate\x12U\n\x08or_match\x18\x01 \x01(\x0b\x32\x41.envoy.api.v2.listener.ListenerFilterChainMatchPredicate.MatchSetH\x00\x12V\n\tand_match\x18\x02 \x01(\x0b\x32\x41.envoy.api.v2.listener.ListenerFilterChainMatchPredicate.MatchSetH\x00\x12M\n\tnot_match\x18\x03 \x01(\x0b\x32\x38.envoy.api.v2.listener.ListenerFilterChainMatchPredicateH\x00\x12\x1c\n\tany_match\x18\x04 \x01(\x08\x42\x07\xfa\x42\x04j\x02\x08\x01H\x00\x12\x38\n\x16\x64\x65stination_port_range\x18\x05 \x01(\x0b\x32\x16.envoy.type.Int32RangeH\x00\x1a]\n\x08MatchSet\x12Q\n\x05rules\x18\x01 \x03(\x0b\x32\x38.envoy.api.v2.listener.ListenerFilterChainMatchPredicateB\x08\xfa\x42\x05\x92\x01\x02\x08\x02\x42\x0b\n\x04rule\x12\x03\xf8\x42\x01\"\xe6\x01\n\x0eListenerFilter\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12-\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructB\x02\x18\x01H\x00\x12,\n\x0ctyped_config\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x12Q\n\x0f\x66ilter_disabled\x18\x04 \x01(\x0b\x32\x38.envoy.api.v2.listener.ListenerFilterChainMatchPredicateB\r\n\x0b\x63onfig_typeB\xdd\x01\n#io.envoyproxy.envoy.api.v2.listenerB\x17ListenerComponentsProtoP\x01Z<github.com/envoyproxy/go-control-plane/envoy/api/v2/listener\xaa\x02\x17\x45nvoy.Api.V2.ListenerNS\xea\x02\x1a\x45nvoy::Api::V2::ListenerNS\xf2\x98\xfe\x8f\x05\x1a\x12\x18\x65nvoy.config.listener.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.api.v2.listener.listener_components_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n#io.envoyproxy.envoy.api.v2.listenerB\027ListenerComponentsProtoP\001Z<github.com/envoyproxy/go-control-plane/envoy/api/v2/listener\252\002\027Envoy.Api.V2.ListenerNS\352\002\032Envoy::Api::V2::ListenerNS\362\230\376\217\005\032\022\030envoy.config.listener.v3\272\200\310\321\006\002\020\001'
  _globals['_FILTER'].fields_by_name['name']._loaded_options = None
  _globals['_FILTER'].fields_by_name['name']._serialized_options = b'\372B\004r\002 \001'
  _globals['_FILTER'].fields_by_name['config']._loaded_options = None
  _globals['_FILTER'].fields_by_name['config']._serialized_options = b'\030\001'
  _globals['_FILTERCHAINMATCH_CONNECTIONSOURCETYPE'].values_by_name["LOCAL"]._loaded_options = None
  _globals['_FILTERCHAINMATCH_CONNECTIONSOURCETYPE'].values_by_name["LOCAL"]._serialized_options = b'\362\230\376\217\005\025\n\023SAME_IP_OR_LOOPBACK'
  _globals['_FILTERCHAINMATCH'].fields_by_name['destination_port']._loaded_options = None
  _globals['_FILTERCHAINMATCH'].fields_by_name['destination_port']._serialized_options = b'\372B\010*\006\030\377\377\003(\001'
  _globals['_FILTERCHAINMATCH'].fields_by_name['source_type']._loaded_options = None
  _globals['_FILTERCHAINMATCH'].fields_by_name['source_type']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_FILTERCHAINMATCH'].fields_by_name['source_ports']._loaded_options = None
  _globals['_FILTERCHAINMATCH'].fields_by_name['source_ports']._serialized_options = b'\372B\r\222\001\n\"\010*\006\030\377\377\003(\001'
  _globals['_FILTERCHAIN'].fields_by_name['tls_context']._loaded_options = None
  _globals['_FILTERCHAIN'].fields_by_name['tls_context']._serialized_options = b'\030\001'
  _globals['_LISTENERFILTERCHAINMATCHPREDICATE_MATCHSET'].fields_by_name['rules']._loaded_options = None
  _globals['_LISTENERFILTERCHAINMATCHPREDICATE_MATCHSET'].fields_by_name['rules']._serialized_options = b'\372B\005\222\001\002\010\002'
  _globals['_LISTENERFILTERCHAINMATCHPREDICATE'].oneofs_by_name['rule']._loaded_options = None
  _globals['_LISTENERFILTERCHAINMATCHPREDICATE'].oneofs_by_name['rule']._serialized_options = b'\370B\001'
  _globals['_LISTENERFILTERCHAINMATCHPREDICATE'].fields_by_name['any_match']._loaded_options = None
  _globals['_LISTENERFILTERCHAINMATCHPREDICATE'].fields_by_name['any_match']._serialized_options = b'\372B\004j\002\010\001'
  _globals['_LISTENERFILTER'].fields_by_name['name']._loaded_options = None
  _globals['_LISTENERFILTER'].fields_by_name['name']._serialized_options = b'\372B\004r\002 \001'
  _globals['_LISTENERFILTER'].fields_by_name['config']._loaded_options = None
  _globals['_LISTENERFILTER'].fields_by_name['config']._serialized_options = b'\030\001'
  _globals['_FILTER']._serialized_start=368
  _globals['_FILTER']._serialized_end=513
  _globals['_FILTERCHAINMATCH']._serialized_start=516
  _globals['_FILTERCHAINMATCH']._serialized_end=1097
  _globals['_FILTERCHAINMATCH_CONNECTIONSOURCETYPE']._serialized_start=1006
  _globals['_FILTERCHAINMATCH_CONNECTIONSOURCETYPE']._serialized_end=1091
  _globals['_FILTERCHAIN']._serialized_start=1100
  _globals['_FILTERCHAIN']._serialized_end=1472
  _globals['_LISTENERFILTERCHAINMATCHPREDICATE']._serialized_start=1475
  _globals['_LISTENERFILTERCHAINMATCHPREDICATE']._serialized_end=1960
  _globals['_LISTENERFILTERCHAINMATCHPREDICATE_MATCHSET']._serialized_start=1854
  _globals['_LISTENERFILTERCHAINMATCHPREDICATE_MATCHSET']._serialized_end=1947
  _globals['_LISTENERFILTER']._serialized_start=1963
  _globals['_LISTENERFILTER']._serialized_end=2193
# @@protoc_insertion_point(module_scope)
