# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/service/route/v3/rds.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/service/route/v3/rds.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.service.discovery.v3 import discovery_pb2 as envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from envoy.annotations import resource_pb2 as envoy_dot_annotations_dot_resource__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n envoy/service/route/v3/rds.proto\x12\x16\x65nvoy.service.route.v3\x1a*envoy/service/discovery/v3/discovery.proto\x1a\x1cgoogle/api/annotations.proto\x1a envoy/annotations/resource.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"(\n\x08RdsDummy:\x1c\x9a\xc5\x88\x1e\x17\n\x15\x65nvoy.api.v2.RdsDummy2\xc6\x03\n\x15RouteDiscoveryService\x12q\n\x0cStreamRoutes\x12,.envoy.service.discovery.v3.DiscoveryRequest\x1a-.envoy.service.discovery.v3.DiscoveryResponse\"\x00(\x01\x30\x01\x12z\n\x0b\x44\x65ltaRoutes\x12\x31.envoy.service.discovery.v3.DeltaDiscoveryRequest\x1a\x32.envoy.service.discovery.v3.DeltaDiscoveryResponse\"\x00(\x01\x30\x01\x12\x8b\x01\n\x0b\x46\x65tchRoutes\x12,.envoy.service.discovery.v3.DiscoveryRequest\x1a-.envoy.service.discovery.v3.DiscoveryResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\"\x14/v3/discovery:routes:\x01*\x1a\x30\x8a\xa4\x96\xf3\x07*\n(envoy.config.route.v3.RouteConfiguration2\xcb\x01\n\x1bVirtualHostDiscoveryService\x12\x80\x01\n\x11\x44\x65ltaVirtualHosts\x12\x31.envoy.service.discovery.v3.DeltaDiscoveryRequest\x1a\x32.envoy.service.discovery.v3.DeltaDiscoveryResponse\"\x00(\x01\x30\x01\x1a)\x8a\xa4\x96\xf3\x07#\n!envoy.config.route.v3.VirtualHostB\x81\x01\n$io.envoyproxy.envoy.service.route.v3B\x08RdsProtoP\x01ZEgithub.com/envoyproxy/go-control-plane/envoy/service/route/v3;routev3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.service.route.v3.rds_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n$io.envoyproxy.envoy.service.route.v3B\010RdsProtoP\001ZEgithub.com/envoyproxy/go-control-plane/envoy/service/route/v3;routev3\272\200\310\321\006\002\020\002'
  _globals['_RDSDUMMY']._loaded_options = None
  _globals['_RDSDUMMY']._serialized_options = b'\232\305\210\036\027\n\025envoy.api.v2.RdsDummy'
  _globals['_ROUTEDISCOVERYSERVICE']._loaded_options = None
  _globals['_ROUTEDISCOVERYSERVICE']._serialized_options = b'\212\244\226\363\007*\n(envoy.config.route.v3.RouteConfiguration'
  _globals['_ROUTEDISCOVERYSERVICE'].methods_by_name['FetchRoutes']._loaded_options = None
  _globals['_ROUTEDISCOVERYSERVICE'].methods_by_name['FetchRoutes']._serialized_options = b'\202\323\344\223\002\031\"\024/v3/discovery:routes:\001*'
  _globals['_VIRTUALHOSTDISCOVERYSERVICE']._loaded_options = None
  _globals['_VIRTUALHOSTDISCOVERYSERVICE']._serialized_options = b'\212\244\226\363\007#\n!envoy.config.route.v3.VirtualHost'
  _globals['_RDSDUMMY']._serialized_start=234
  _globals['_RDSDUMMY']._serialized_end=274
  _globals['_ROUTEDISCOVERYSERVICE']._serialized_start=277
  _globals['_ROUTEDISCOVERYSERVICE']._serialized_end=731
  _globals['_VIRTUALHOSTDISCOVERYSERVICE']._serialized_start=734
  _globals['_VIRTUALHOSTDISCOVERYSERVICE']._serialized_end=937
# @@protoc_insertion_point(module_scope)
